FmodStudio

Struct FmodStudio 

pub struct FmodStudio(pub Studio);
A resource that wraps the Studio object from the FMOD library.

This struct provides convenient access to the FMOD Studio API within the Bevy ECS. It derives Deref and DerefMut to allow direct access to the inner Studio object.

Tuple Fields

0: Studio

Methods from Deref<Target = Studio>

pub fn as_mut_ptr(&self) -> *mut FMOD_STUDIO_SYSTEM

pub fn is_valid(&self) -> bool

pub fn set_advanced_settings( &self, settings: StudioAdvancedSettings, ) -> Result<(), Error>

pub fn get_advanced_settings(&self) -> Result<StudioAdvancedSettings, Error>

pub fn initialize( &self, maxchannels: i32, studioflags: impl Into<u32>, flags: impl Into<u32>, extradriverdata: Option<*mut c_void>, ) -> Result<(), Error>

pub fn release(&self) -> Result<(), Error>

pub fn update(&self) -> Result<(), Error>

pub fn get_core_system(&self) -> Result<System, Error>

pub fn get_event(&self, path_or_id: &str) -> Result<EventDescription, Error>

pub fn get_bus(&self, path_or_id: &str) -> Result<Bus, Error>

pub fn get_vca(&self, path_or_id: &str) -> Result<Vca, Error>

pub fn get_bank(&self, path_or_id: &str) -> Result<Bank, Error>

pub fn get_event_by_id(&self, id: Guid) -> Result<EventDescription, Error>

pub fn get_bus_by_id(&self, id: Guid) -> Result<Bus, Error>

pub fn get_vca_by_id(&self, id: Guid) -> Result<Vca, Error>

pub fn get_bank_by_id(&self, id: Guid) -> Result<Bank, Error>

pub fn get_sound_info(&self, key: &str) -> Result<SoundInfo, Error>

pub fn get_parameter_description_by_name( &self, name: &str, ) -> Result<ParameterDescription, Error>

pub fn get_parameter_description_by_id( &self, id: ParameterId, ) -> Result<ParameterDescription, Error>

pub fn get_parameter_label_by_name( &self, name: &str, labelindex: i32, size: i32, ) -> Result<(String, i32), Error>

pub fn get_parameter_label_by_id( &self, id: ParameterId, labelindex: i32, size: i32, ) -> Result<(String, i32), Error>

pub fn get_parameter_by_id(&self, id: ParameterId) -> Result<(f32, f32), Error>

pub fn set_parameter_by_id( &self, id: ParameterId, value: f32, ignoreseekspeed: bool, ) -> Result<(), Error>

pub fn set_parameter_by_id_with_label( &self, id: ParameterId, label: &str, ignoreseekspeed: bool, ) -> Result<(), Error>

pub fn set_parameters_by_i_ds( &self, ids: ParameterId, values: *mut f32, count: i32, ignoreseekspeed: bool, ) -> Result<(), Error>

pub fn get_parameter_by_name(&self, name: &str) -> Result<(f32, f32), Error>

pub fn set_parameter_by_name( &self, name: &str, value: f32, ignoreseekspeed: bool, ) -> Result<(), Error>

pub fn set_parameter_by_name_with_label( &self, name: &str, label: &str, ignoreseekspeed: bool, ) -> Result<(), Error>

pub fn lookup_id(&self, path: &str) -> Result<Guid, Error>

pub fn lookup_path(&self, id: Guid) -> Result<String, Error>

pub fn get_num_listeners(&self) -> Result<i32, Error>

pub fn set_num_listeners(&self, numlisteners: i32) -> Result<(), Error>

pub fn get_listener_attributes( &self, index: i32, ) -> Result<(Attributes3d, Vector), Error>

pub fn set_listener_attributes( &self, index: i32, attributes: Attributes3d, attenuationposition: Option<Vector>, ) -> Result<(), Error>

pub fn get_listener_weight(&self, index: i32) -> Result<f32, Error>

pub fn set_listener_weight(&self, index: i32, weight: f32) -> Result<(), Error>

pub fn load_bank_file( &self, filename: &str, flags: impl Into<u32>, ) -> Result<Bank, Error>

pub fn load_bank_memory( &self, buffer: &[u8], flags: impl Into<u32>, ) -> Result<Bank, Error>

pub fn load_bank_custom( &self, info: BankInfo, flags: impl Into<u32>, ) -> Result<Bank, Error>

pub fn register_plugin(&self, description: DspDescription) -> Result<(), Error>

pub fn unregister_plugin(&self, name: &str) -> Result<(), Error>

pub fn unload_all(&self) -> Result<(), Error>

pub fn flush_commands(&self) -> Result<(), Error>

pub fn flush_sample_loading(&self) -> Result<(), Error>

pub fn start_command_capture( &self, filename: &str, flags: impl Into<u32>, ) -> Result<(), Error>

pub fn stop_command_capture(&self) -> Result<(), Error>

pub fn load_command_replay( &self, filename: &str, flags: impl Into<u32>, ) -> Result<CommandReplay, Error>

pub fn get_bank_count(&self) -> Result<i32, Error>

pub fn get_bank_list(&self, capacity: i32) -> Result<Vec<Bank>, Error>

pub fn get_parameter_description_count(&self) -> Result<i32, Error>

pub fn get_parameter_description_list( &self, capacity: i32, ) -> Result<Vec<ParameterDescription>, Error>

pub fn get_cpu_usage(&self) -> Result<(StudioCpuUsage, CpuUsage), Error>

pub fn get_buffer_usage(&self) -> Result<BufferUsage, Error>

pub fn reset_buffer_usage(&self) -> Result<(), Error>

pub fn set_callback( &self, callback: Option<unsafe extern "C" fn(*mut FMOD_STUDIO_SYSTEM, u32, *mut c_void, *mut c_void) -> i32>, callbackmask: impl Into<u32>, ) -> Result<(), Error>

pub fn set_user_data(&self, userdata: *mut c_void) -> Result<(), Error>

pub fn get_user_data(&self) -> Result<*mut c_void, Error>

pub fn get_memory_usage(&self) -> Result<MemoryUsage, Error>